// automatically generated file.
#define Z3_MAJOR_VERSION   4
#define Z3_MINOR_VERSION   13
#define Z3_BUILD_NUMBER    0
#define Z3_REVISION_NUMBER 0

#define Z3_FULL_VERSION    "4.13.0.0 3049f578a8f98a0b0992eca193afe57a73b30ca3 z3-4.8.4-8360-g3049f578a"
#define Z3GITHASH 3049f578a8f98a0b0992eca193afe57a73b30ca3
